<?php


/*
This plugin is released under 'private license' by Di Themes ( http://DiThemes.com ).
Restriction: you CAN NOT directly or indirectly (or after modify) distribute it on private or public host.
You can ONLY use this plugin with released products by Di Themes ( http://DiThemes.com ).
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Start below.
class Di_eCommerce_Custom_Header {

	function __construct() {
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue' ) );
		add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
		add_action( 'save_post',      array( $this, 'save' ) );
	}

	function add_meta_box( $post_type ) {

		$allow_posts = array( 'post', 'page' );
		if( in_array( $post_type, $allow_posts ) ) {
			add_meta_box(
				'di_ecommerce_custom_header_cntnr',
				__( 'Custom Header Image (1350×260)', 'di-ecommerce-pro' ),
				array( $this, 'render_meta_box_content' ),
				$post_type,
				'side',
				'low'
			);
		}
	}

	function render_meta_box_content( $post ) {

		// Add an nonce field so we can check for it later.
		wp_nonce_field( 'di_ecommerce_custom_header_key', 'di_ecommerce_custom_header_key_nonce' );

		global $_wp_additional_image_sizes;
		$image_id = intval( get_post_meta( $post->ID, '_di_ecommerce_cstm_hdrimg', true ) );

		if ( $image_id && get_post( $image_id ) ) {

			$thumbnail_link = wp_get_attachment_url( $image_id );

			if ( ! empty( $thumbnail_link ) ) {

				$content = '<img src="' . $thumbnail_link . '" style="width:254px;height:auto;border:0;" />';

				$content .= '<p class="hide-if-no-js"><a href="javascript:;" id="remove_dib_custom_header_image_button" >' . esc_html__( 'Remove Custom Header Image', 'text-domain' ) . '</a></p>';

				$content .= '<input type="hidden" id="upload_dib_custom_header_image" name="di_ecommerce_cstm_hdrimg_name" value="' . esc_attr( $image_id ) . '" />';
			}

		} else {

			$content = '<img src="" style="width:254px;height:auto;border:0;display:none;" />';

			$content .= '<p class="hide-if-no-js"><a href="javascript:;" id="upload_dib_custom_header_image_button" id="set-listing-image" >' . esc_html__( 'Set Custom Header Image', 'text-domain' ) . '</a></p>';

			$content .= '<input type="hidden" id="upload_dib_custom_header_image" name="di_ecommerce_cstm_hdrimg_name" value="" />';

		}

		echo $content;

	}

	function save( $post_id ) {

		// Verify that the nonce is valid.
		if( ! isset( $_POST['di_ecommerce_custom_header_key_nonce'] ) ) {
			return $post_id;
		}

		$nonce = wp_unslash( $_POST['di_ecommerce_custom_header_key_nonce'] );
		if( ! wp_verify_nonce( $nonce, 'di_ecommerce_custom_header_key' ) ) {
			return $post_id;
		}

		// nothing to do, if auto saving
		if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		// validate post type
		if( ! in_array( $_POST['post_type'], array( 'page', 'post' ) ) ) {
			return $post_id;
		}

		// Check current user permission.
		if( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}

		/* OK, it's safe for us to save the data now. */

		if( isset( $_POST['di_ecommerce_cstm_hdrimg_name'] ) ) {
			$image_id = (int) $_POST['di_ecommerce_cstm_hdrimg_name'];
			update_post_meta( $post_id, '_di_ecommerce_cstm_hdrimg', $image_id );
		}
	}

	function enqueue() {

		wp_enqueue_script( 'di-ecommerce-admin-custom-header-js', DI_ECOMMERCE_PRO_URL . 'assets/js/admin_custom_header.js', array( 'jquery' ), DI_ECOMMERCE_PRO_VERSION, true );

		wp_localize_script(
			'di-ecommerce-admin-custom-header-js',
			'DieCommerceAdminCustomHeaderImgJsLocalization',
			array(
				'mediatitle'	=> __( 'Custom Header Image', 'di-ecommerce-pro' ),
				'mediabtntxt'	=> __( 'Select', 'di-ecommerce-pro' ),
				'removehdrtxt'	=> __( 'Remove Custom Header Image', 'di-ecommerce-pro' ),
				'addhdrtxt'		=> __( 'Set Custom Header Image', 'di-ecommerce-pro' ),
			)
		);

	}
}

if( is_admin() ) {
	add_action( 'load-post.php', 'di_ecommerce_custom_header_int_func' );
	add_action( 'load-post-new.php', 'di_ecommerce_custom_header_int_func' );
}

function di_ecommerce_custom_header_int_func() {
	new Di_eCommerce_Custom_Header();
}
