<?php

/*
This plugin is released under 'private license' by Di Themes ( http://DiThemes.com ).
Restriction: you CAN NOT directly or indirectly (or after modify) distribute it on private or public host.
You can ONLY use this plugin with released products by Di Themes ( http://DiThemes.com ).
*/

if ( ! defined( 'ABSPATH' ) ) { exit; }

class Di_eCommerce_Pro_Widget_Creator {

	function __construct() {
		add_action( 'load-widgets.php', array( $this, 'enqueue' ) );
		add_action( 'admin_print_scripts', array( $this, 'render_widget_add_form' ) );
		add_action( 'init', array( $this, 'save_widget_add_from' ) );
		add_action( 'init', array( $this, 'register_sidebars' ) );
		add_action( 'plugins_loaded', array( $this, 'delete_a_widget' ) );
	}

	function enqueue() {
		// Load widget_areas.js
		wp_enqueue_script( 'di-ecommerce-admin-widget-areas-js', DI_ECOMMERCE_PRO_URL . 'assets/js/admin_widget_areas.js', array( 'jquery' ), DI_ECOMMERCE_PRO_VERSION, true );

		wp_localize_script(
			'di-ecommerce-admin-widget-areas-js',
			'DieCommerceAdminWidgetAreaJsLocalization',
			array(
				'confirm'		=> __( 'Delete This Area', 'di-ecommerce-pro' ),
				'confirmAlert'	=> __( 'It will delete this created widget area. Sure?', 'di-ecommerce-pro' ),
				'nonce'			=> esc_attr( wp_create_nonce( 'di_ecommerce_pro_widget_creator_delete_nonce_key' ) ),
			)
		);
		// Load widget_areas.css
		wp_enqueue_style( 'di-ecommerce-admin-widget-areas-css',  DI_ECOMMERCE_PRO_URL . 'assets/css/admin_widget_areas.css', DI_ECOMMERCE_PRO_VERSION, true );
	}

	function render_widget_add_form() {
		?>
		<script type="text/html" id="di-ecommerce-add-widget-template">
			<div id="widget-creator-outer-div" class="widgets-holder-wrapd">

				<div class="sidebar-name creatertitle">
					<h3><?php _e( 'Create Widget Area', 'di-ecommerce-pro' ); ?></h3>
				</div>

				<div class="sidebar-description">
					<p class="description"><?php _e( 'It uses to display different sidebar on different page or post. This created widget area can be selected on page or post edit screen.', 'di-ecommerce-pro' ); ?></p>
				</div>

				<form action="" method="post">
					<div class="typetext">
					
						<?php
						wp_nonce_field( 'di_ecommerce_pro_widget_creator_key', 'di_ecommerce_pro_widget_creator_key_nonce' );
						?>

						<input class="typetextinput" type="text" name="widgetcretor"
						title="<?php esc_attr_e( 'Name', 'di-ecommerce-pro' ); ?>"
						placeholder="<?php esc_attr_e( 'Name...', 'di-ecommerce-pro' ); ?>" />
					</div>
					<div class="typesubmit">
						<input class="button button-primary button-large typesubmitbutton" type="submit" name="widgetcretorsubmit" value="<?php esc_attr_e( 'Create Widget Area', 'di-ecommerce-pro' ); ?>" />
					</div>
				</form>

			</div>
		</script>
		<?php
	}

	function save_widget_add_from() {

		if( isset( $_POST['widgetcretorsubmit'] ) ) {

			if( isset( $_POST['widgetcretor'] ) && ! empty( $_POST['widgetcretor'] ) ) {

				//verify nonce
				if( ! isset( $_POST['di_ecommerce_pro_widget_creator_key_nonce'] ) ) {
					return;
				}

				$nonce = wp_unslash( $_POST['di_ecommerce_pro_widget_creator_key_nonce'] );
				if( ! wp_verify_nonce( $nonce, 'di_ecommerce_pro_widget_creator_key' ) ) {
					return;
				}

				$id = sanitize_text_field( $_POST['widgetcretor'] );

				if( get_option( '_di_ecommerce_created_widgets', '' ) ) {
					// append stored value with new one
					$arr = get_option( '_di_ecommerce_created_widgets' );
					array_push( $arr , $id ); // just push new id in $arr
					$arr = array_unique( $arr ); // Remove same names of array value
					update_option( '_di_ecommerce_created_widgets', $arr );
				} else {
					// store first time value
					$arr = array( $id );
					update_option( '_di_ecommerce_created_widgets', $arr );
				}

			}
		}
	}

	function register_sidebars() {

		if( get_option( '_di_ecommerce_created_widgets', '' ) ) {

			$allwidgetsarr = get_option( '_di_ecommerce_created_widgets' );

			foreach( $allwidgetsarr as $allwidgetsingle ) {
				$allwidgetsingle = stripslashes( $allwidgetsingle );
				register_sidebar( array(
					'name'			=> $allwidgetsingle,
					'id'			=> $this->strip_specail_chars( $allwidgetsingle ),
					'description'	=> $allwidgetsingle . ' ' . __( 'Widgets', 'di-ecommerce-pro' ),
					'before_widget'	=> '<div id="%1$s" class="widget_sidebar_main clearfix %2$s">',
					'after_widget'	=> '</div>',
					'before_title'	=> '<h3 class="right-widget-title">',
					'after_title'	=> '</h3>',
					'class'			=> 'di-ecommerce-widget-admin',
				) );
			}
		}
	}

	function delete_a_widget() {

		if( isset( $_POST['diwidgetdeletebttnsigle'] ) ) {
			
			if( isset( $_POST['diwidgettodelete'] ) && ! empty( $_POST['diwidgettodelete'] ) ) {

				//verify nonce
				if( ! isset( $_POST['di_ecommerce_pro_widget_creator_delete_nonce'] ) ) {
					return;
				}

				$nonce = wp_unslash( $_POST['di_ecommerce_pro_widget_creator_delete_nonce'] );
				if( ! wp_verify_nonce( $nonce, 'di_ecommerce_pro_widget_creator_delete_nonce_key' ) ) {
					return;
				}

				//now we have a name of widget to delete.
				$idtodelete = addslashes( $_POST['diwidgettodelete'] );

				if( get_option( '_di_ecommerce_created_widgets', '' ) ) {
					// remove this from stored array
					$arr = get_option( '_di_ecommerce_created_widgets' );
					if( in_array( $idtodelete, $arr ) ) {
						if( ( $key = array_search( $idtodelete, $arr ) ) !== false ) {
							unset( $arr[ $key ] );
						}
						$arr = array_unique( $arr );
						update_option( '_di_ecommerce_created_widgets', $arr );
					}
				}
			}
		}
	}
	
	function strip_specail_chars( $str ) {
		return strtolower( preg_replace( '/[^a-zA-Z0-9-_\.]/','', $str ) );
	}

}
new Di_eCommerce_Pro_Widget_Creator();
